@@ -8,18 +8,19 @@ DeregisterEventSource = windll.advapi32.DeregisterEventSource
 ReportEventW = windll.advapi32.ReportEventW
 
 # From http://msdn.microsoft.com/en-us/library/windows/desktop/aa363679%28v=VS.85%29.aspx
-EVENTLOG_SUCCESS = 0x0000 
-EVENTLOG_AUDIT_FAILURE = 0x0010 
-EVENTLOG_AUDIT_SUCCESS = 0x0008 
-EVENTLOG_ERROR_TYPE = 0x0001 
-EVENTLOG_INFORMATION_TYPE = 0x0004 
-EVENTLOG_WARNING_TYPE = 0x0002 
+EVENTLOG_SUCCESS = 0x0000
+EVENTLOG_AUDIT_FAILURE = 0x0010
+EVENTLOG_AUDIT_SUCCESS = 0x0008
+EVENTLOG_ERROR_TYPE = 0x0001
+EVENTLOG_INFORMATION_TYPE = 0x0004
+EVENTLOG_WARNING_TYPE = 0x0002
+
 
 def register_application(app_name, message_file_path=None):
     """Registers an application as an event log source so it can later create events.
-    
-    app_name - Application name (use the same name later when registering the event source)
-    message_file_path - resource DLL file path
+
+    :param app_name: Application name (use the same name later when registering the event source)
+    :param message_file_path: resource DLL file path
     """
     # See http://msdn.microsoft.com/en-us/library/windows/desktop/aa363661%28v=VS.85%29.aspx
 
@@ -34,13 +35,15 @@ def register_application(app_name, message_file_path=None):
     event_log['Application'][app_name] = None
     app_key = event_log['Application'][app_name]
     app_key.values_store['EventMessageFile'] = value_factory.by_value(message_file_path)
-    app_key.values_store['TypesSupported'] = value_factory.by_value(7) # All severity types
+    app_key.values_store['TypesSupported'] = value_factory.by_value(7)  # All severity types
+
 
 def unregister_application(app_name):
     """Unregisters an application as a log source by removing it from the registry."""
     event_log = LocalComputer().local_machine['SYSTEM']['CurrentControlSet']['Services']['Eventlog']
     event_log['Application'].pop(app_name, None)
 
+
 def register_event_source(app_name):
     """Registers an event source and returns an open handle. Raises WinError on error."""
     handle = RegisterEventSourceW(None, unicode(app_name))
@@ -48,20 +51,22 @@ def register_event_source(app_name):
         raise WinError()
     return handle
 
+
 def deregister_event_source(handle):
     """Closes an open event source handle."""
     DeregisterEventSource(handle)
 
+
 def report_event(handle, type, category, event_id, strings, raw_data):
     """Reports an event to Windows event log. Raises WinError on error.
-    
-    handle - handle to an open event source, previously opened with register_event_source
-    type - event type: one of the EVENTLOG_xxxx constants
-    category - category to use (number). If using our resource DLL, leave this as 0.
-    event_id - event ID to use (number).
-    strings - a list of strings that will be formatted as the event message. IF using our resource DLL, only a single
-              string is supported.
-    raw_data - a blob (string)
+
+    :param handle: handle to an open event source, previously opened with register_event_source
+    :param type: event type: one of the EVENTLOG_xxxx constants
+    :param category: category to use (number). If using our resource DLL, leave this as 0.
+    :param event_id: event ID to use (number).
+    :param strings: a list of strings that will be formatted as the event message. IF using our resource DLL, only a single
+                    string is supported.
+    :param raw_data: a blob (string)
     """
     # See http://msdn.microsoft.com/en-us/library/windows/desktop/aa363679%28v=VS.85%29.aspx
     raw_data_len = 0 if raw_data is None else len(raw_data)
@@ -72,6 +77,7 @@ def report_event(handle, type, category, event_id, strings, raw_data):
     if result != 1:
         raise WinError()
 
+
 class Win32EventLogHandler(Handler, StringFormatterHandlerMixin):
     default_format_string = "{record.message}"
 
@@ -101,7 +107,7 @@ class Win32EventLogHandler(Handler, StringFormatterHandlerMixin):
             id = dic.get('eventid', 0)
             if id != 0:
                 return id
-        
+
         # TODO: warn on debug that we have no id for this event.
         return 0
 
@@ -111,7 +117,7 @@ class Win32EventLogHandler(Handler, StringFormatterHandlerMixin):
             if category != 0:
                 return category
         return 0
-        
+
     def get_event_type(self, record):
         return self._type_map.get(record.level, self._default_type)
 
@@ -128,4 +134,4 @@ class Win32EventLogHandler(Handler, StringFormatterHandlerMixin):
         type = self.get_event_type(record)
         message = self.format(record)
         raw_data = self.get_raw_data(record)
-        report_event(self._win32_handle, type, cat, id, [ message ], raw_data)
+        report_event(self._win32_handle, type, cat, id, [message], raw_data)
